package Data::HashMap::Shared::I16;
use strict;
use warnings;
use Data::HashMap::Shared;
our $VERSION = '0.02';

sub import {
    $^H{"Data::HashMap::Shared::I16/shm_i16_put"}        = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_get"}        = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_remove"}     = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_exists"}     = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_incr"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_decr"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_incr_by"}    = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_size"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_keys"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_values"}     = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_items"}      = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_each"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_iter_reset"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_clear"}      = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_to_hash"}    = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_max_entries"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_get_or_set"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_put_ttl"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_max_size"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_ttl"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_cursor"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_cursor_next"}  = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_cursor_seek"}  = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_ttl_remaining"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_capacity"}     = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_tombstones"}   = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_cursor_reset"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_take"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_pop"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_shift"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_drain"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_flush_expired"}  = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_flush_expired_partial"} = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_mmap_size"}      = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_touch"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_reserve"}         = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_stat_evictions"}  = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_stat_expired"}    = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_stat_recoveries"}    = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_arena_used"}       = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_arena_cap"}        = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_add"}              = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_update"}           = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_swap"}             = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_cas"}             = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_persist"}         = 1;
    $^H{"Data::HashMap::Shared::I16/shm_i16_set_ttl"}         = 1;
}

1;
