/* shm_si16.h -- string -> int16 shared hashmap */
#define SHM_PREFIX       shm_si16
#define SHM_NODE_TYPE    ShmNodeSI16
#define SHM_VARIANT_ID   7
#define SHM_VAL_INT_TYPE int16_t
#define SHM_HAS_COUNTERS
#include "shm_generic.h"
